use super::api::ErrorModel;
use std::io;

#[derive(Debug)]
pub enum GenericError {
    TomlError(toml::de::Error),
    YepzonServerError(ErrorModel),
    MinreqError(minreq::Error),
    ChronoParseError(chrono::ParseError),
    IOError(io::Error),
    FromUTF8Error(std::string::FromUtf8Error),
    OutOfLocations,
}

impl From<toml::de::Error> for GenericError {
    fn from(error: toml::de::Error) -> Self {
        GenericError::TomlError(error)
    }
}

impl From<minreq::Error> for GenericError {
    fn from(error: minreq::Error) -> Self {
        GenericError::MinreqError(error)
    }
}

impl From<chrono::ParseError> for GenericError {
    fn from(error: chrono::ParseError) -> Self {
        GenericError::ChronoParseError(error)
    }
}

impl From<ErrorModel> for GenericError {
    fn from(error: ErrorModel) -> Self {
        GenericError::YepzonServerError(error)
    }
}

impl From<io::Error> for GenericError {
    fn from(error: io::Error) -> Self {
        GenericError::IOError(error)
    }
}

impl From<std::string::FromUtf8Error> for GenericError {
    fn from(error: std::string::FromUtf8Error) -> Self {
        GenericError::FromUTF8Error(error)
    }
}
